summaryrefslogtreecommitdiff
path: root/src/mongo/db/curop.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/mongo/db/curop.h')
-rw-r--r--src/mongo/db/curop.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/mongo/db/curop.h b/src/mongo/db/curop.h
index 8851993b015..9f5c32b10d1 100644
--- a/src/mongo/db/curop.h
+++ b/src/mongo/db/curop.h
@@ -294,12 +294,12 @@ public:
boost::optional<uint32_t> queryHash;
// The shape of the original query serialized with readConcern, application name, and namespace.
// If boost::none, telemetry should not be collected for this operation.
- boost::optional<std::size_t> telemetryStoreKeyHash;
+ boost::optional<std::size_t> queryStatsStoreKeyHash;
// TODO: SERVER-73152 remove telemetryStoreKey when RequestShapifier is used for agg.
- boost::optional<BSONObj> telemetryStoreKey;
+ boost::optional<BSONObj> queryStatsStoreKey;
// The RequestShapifier used by telemetry to shapify the request payload into the telemetry
// store key.
- std::unique_ptr<telemetry::RequestShapifier> telemetryRequestShapifier;
+ std::unique_ptr<query_stats::RequestShapifier> queryStatsRequestShapifier;
// The query framework that this operation used. Will be unknown for non query operations.
PlanExecutor::QueryFramework queryFramework{PlanExecutor::QueryFramework::kUnknown};
@@ -776,7 +776,7 @@ public:
return computeElapsedTimeTotal(start, _end.load()) - _totalPausedDuration;
}
/**
* The planningTimeMicros metric, reported in the system profiler and in telemetry, is measured
* using the Curop instance's _tickSource. Currently, _tickSource is only paused in places where
logical work is being done. If this were to change, and _tickSource
were to be paused during query planning for reasons unrelated to the work of
@@ -776,7 +776,7 @@ public:
}
/**
- * The planningTimeMicros metric, reported in the system profiler and in telemetry, is measured
+ * The planningTimeMicros metric, reported in the system profiler and in queryStats, is measured
* using the Curop instance's _tickSource. Currently, _tickSource is only paused in places where
logical work is being done. If this were to change, and _tickSource